EXPORTS
	??0TMMFileHandleSource@@QAE@AAVRFile@@@Z @ 1 NONAME ; TMMFileHandleSource::TMMFileHandleSource(class RFile &)
	??0TMMFileHandleSource@@QAE@AAVRFile@@ABVTDesC16@@@Z @ 2 NONAME ; TMMFileHandleSource::TMMFileHandleSource(class RFile &, class TDesC16 const &)
	??0TMMFileHandleSource@@QAE@AAVRFile@@ABVTDesC16@@W4TIntent@ContentAccess@@@Z @ 3 NONAME ; TMMFileHandleSource::TMMFileHandleSource(class RFile &, class TDesC16 const &, enum ContentAccess::TIntent)
	??0TMMFileSource@@QAE@ABVTDesC16@@0@Z @ 4 NONAME ; TMMFileSource::TMMFileSource(class TDesC16 const &, class TDesC16 const &)
	??0TMMFileSource@@QAE@ABVTDesC16@@0W4TIntent@ContentAccess@@@Z @ 5 NONAME ; TMMFileSource::TMMFileSource(class TDesC16 const &, class TDesC16 const &, enum ContentAccess::TIntent)
	??0TMMFileSource@@QAE@ABVTDesC16@@@Z @ 6 NONAME ; TMMFileSource::TMMFileSource(class TDesC16 const &)
	??0TMMSource@@IAE@VTUid@@ABVTDesC16@@W4TIntent@ContentAccess@@@Z @ 7 NONAME ; TMMSource::TMMSource(class TUid, class TDesC16 const &, enum ContentAccess::TIntent)
	?Handle@TMMFileHandleSource@@QBEAAVRFile@@XZ @ 8 NONAME ; class RFile & TMMFileHandleSource::Handle(void) const
	?Intent@TMMSource@@QBE?AW4TIntent@ContentAccess@@XZ @ 9 NONAME ; enum ContentAccess::TIntent TMMSource::Intent(void) const
	?Name@TMMFileSource@@QBEABVTDesC16@@XZ @ 10 NONAME ; class TDesC16 const & TMMFileSource::Name(void) const
	?SourceType@TMMSource@@QBE?AVTUid@@XZ @ 11 NONAME ; class TUid TMMSource::SourceType(void) const
	?UniqueId@TMMSource@@QBEABVTDesC16@@XZ @ 12 NONAME ; class TDesC16 const & TMMSource::UniqueId(void) const
	??0TMMFileHandleSource@@QAE@AAVRFile@@ABVTDesC16@@W4TIntent@ContentAccess@@H@Z @ 13 NONAME ; TMMFileHandleSource::TMMFileHandleSource(class RFile &, class TDesC16 const &, enum ContentAccess::TIntent, int)
	??0TMMFileSource@@QAE@ABVTDesC16@@0W4TIntent@ContentAccess@@H@Z @ 14 NONAME ; TMMFileSource::TMMFileSource(class TDesC16 const &, class TDesC16 const &, enum ContentAccess::TIntent, int)
	??0TMMSource@@IAE@VTUid@@ABVTDesC16@@W4TIntent@ContentAccess@@H@Z @ 15 NONAME ; TMMSource::TMMSource(class TUid, class TDesC16 const &, enum ContentAccess::TIntent, int)
	?IsUIEnabled@TMMSource@@QBEHXZ @ 16 NONAME ; int TMMSource::IsUIEnabled(void) const

